aboutsummaryrefslogtreecommitdiff
path: root/engines/sci/sfx/sfx_player.h
diff options
context:
space:
mode:
authorAndre Heider2009-02-24 18:31:05 +0000
committerAndre Heider2009-02-24 18:31:05 +0000
commit357299c5705d6856e070e537610275f1943e6653 (patch)
tree3a778bb49af51f3633d594af46e39e3bd0323c5d /engines/sci/sfx/sfx_player.h
parent3082586230688f27badf707faf95cadc8f761b21 (diff)
downloadscummvm-rg350-357299c5705d6856e070e537610275f1943e6653.tar.gz
scummvm-rg350-357299c5705d6856e070e537610275f1943e6653.tar.bz2
scummvm-rg350-357299c5705d6856e070e537610275f1943e6653.zip
substitute all time related functions, removing sci_gettime sci_get_current_time altogether.
svn-id: r38845
Diffstat (limited to 'engines/sci/sfx/sfx_player.h')
-rw-r--r--engines/sci/sfx/sfx_player.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/engines/sci/sfx/sfx_player.h b/engines/sci/sfx/sfx_player.h
index 68a915c3a0..8718622428 100644
--- a/engines/sci/sfx/sfx_player.h
+++ b/engines/sci/sfx/sfx_player.h
@@ -32,6 +32,8 @@
#include "sci/sfx/sfx_iterator.h"
#include "sci/include/sciresource.h"
+#include "common/scummsys.h"
+
namespace Sci {
typedef void tell_synth_func(int buf_nr, byte *buf);
@@ -55,10 +57,10 @@ struct sfx_player_t {
** Returns : (int) SFX_OK on success, SFX_ERROR on failure
*/
- int (*add_iterator)(song_iterator_t *it, GTimeVal start_time);
+ int (*add_iterator)(song_iterator_t *it, uint32 start_time);
/* Adds an iterator to the song player
** Parameters: (songx_iterator_t *) it: The iterator to play
** (GTimeVal) start_time: The time to assume as the
** time the first MIDI command executes at
** Returns : (int) SFX_OK on success, SFX_ERROR on failure
** The iterator should not be cloned (to avoid memory leaks) and
@@ -55,10 +57,10 @@ struct sfx_player_t {
/* Adds an iterator to the song player
** Parameters: (songx_iterator_t *) it: The iterator to play
- ** (GTimeVal) start_time: The time to assume as the
+ ** (uint32) start_time: The time to assume as the
** time the first MIDI command executes at
** Returns : (int) SFX_OK on success, SFX_ERROR on failure